Crate wolfram_library_link_sys
source ·Expand description
Automatically generated bindings to the Wolfram LibraryLink C API.
Re-exports
pub use self::MNumericArray_Data_Type::Type as numericarray_data_t;pub use self::MNumericArray_Convert_Method::Type as numericarray_convert_method_t;pub use self::MImage_Data_Type::Type as imagedata_t;pub use self::MImage_CS_Type::Type as colorspace_t;Modules
Structs
Platform specific variants in mcomplex.h
Constants
Type Definitions
Incomplete types
The rune type below is declared to be an
int'' instead of the more natural unsigned long’’ or ``long’’. Two things are happening here. It is not
unsigned so that EOF (-1) can be naturally assigned to it and used. Also,
it looks like 10646 will be a 31 bit standard. This means that if your
ints cannot hold 32 bits, you will be in trouble. The reason an int was
chosen over a long is that the is*() and to*() routines take ints (says
ANSI C), but they use __darwin_ct_rune_t instead of int. By changing it
here, you lose a bit of ANSI conformance, but your programs will still
work.Error types for LibraryErrorHandler
7.18.1.3 Fastest-width integer types
7.18.1.2 Minimum-width integer types
This defines the size of syscall arguments after copying into the kernel:
These types are used for reserving the largest possible size.
Unions
mbstate_t is an opaque object to keep conversion state, during multibyte
stream conversions. The content must not be referenced by user programs.